XML Security Library: Related

Home Download News Documentation FAQ Tutorial API reference Examples XML Digital Signature Online Verifier XML Encryption XML Canonicalization Reporting Bugs Mailing list Related Authors
# Related ### Books Secure XML: The New Syntax for Signatures and Encryption Donald E. Eastlake XML Security Blake Dournaee Securing Web Services with WS-Security : Demystifying WS-Security, WS-Policy, SAML, XML Signature, and XML Encryption Jothy Rosenberg Applied Cryptography: Protocols, Algorithms, and Source Code in C, Second Edition Bruce Schneier Practical Cryptography Niels Ferguson, Bruce Schneier Secrets and Lies : Digital Security in a Networked World Bruce Schneier Web Services Security Mark O'Neill Public Key Infrastructure: Building Trusted Applications and Web Services John R. Vacca More books ... ### Dependencies LibXML - GNOME XML library. LibXSLT - GNOME XSLT / EXSLT library. OpenSSL - SSL / TLS implementation. GnuTLS Libgcrypt NSS - Mozilla cryptographic library. ### Projects Windows binaries for XML Security Library from Igor Zlatkovic. XMLSec Library is included as part of Debian GNU/Linux. For more information see the coordination page. XMLSec Library FreeBSD and OpenBSD ports. PyXMLSec Library - Python bindings for XMLSec Library. Lasso Library - the Liberty Alliance standards implementation. Glasnost - content management, electronic vote and groupware sysem. OpenSAML - an open source implementation of SAML 1.0 specification. PKCS11 support for XML Security Library 0.0.X. The BananaHead Point Of Sale project. ### Specifcations XML Signature Syntax and Processing Specification (working group). XML Encryption Syntax and Processing Specification (working group). XML Key Management Specification (working group). Extensible Markup Language (XML) 1.0 Specification. Namespaces in XML. XML Path Language (XPath) Version 1.0. XML Pointer language (XPointer). ### Articles XML Security page - Christian Geuer-Pollmann's collection of links about XML Security. An Introduction to XML Encryption and XML Signature. ZVON.org - the guide to the XML galaxy. Securing Web Services by Rich Salz, XML.com. Tools for securing your XML documents by Brian Schaffner, Builder.com. XML Benchmark.